#include <FileManager.h>
#include <stdexcept>

namespace DataExporter_ns
{

//==============================================================================
//      FileManager::FileManager()
//==============================================================================
FileManager::FileManager(Tango::DeviceImpl* deviceImpl_p,
    boost::filesystem::path& path) : Tango::LogAdapter(deviceImpl_p)
{
    DEBUG_STREAM << "FileManager::FileManager()" << endl;

    m_inputFileStream.open(path.string(), std::ios::binary | std::ios::ate);

    m_inputFileSize = m_inputFileStream.tellg();

    m_inputFileStream.seekg(0, m_inputFileStream.beg);
}

//==============================================================================
//      FileManager::~FileManager()
//==============================================================================
FileManager::~FileManager()
{
    DEBUG_STREAM << "FileManager::~FileManager()" << endl;

    m_inputFileStream.close();
}

//==============================================================================
//      FileManager::create()
//==============================================================================
FileManager::SP FileManager::create(Tango::DeviceImpl* deviceImpl_p,
    boost::filesystem::path& path)
{
    FileManager::SP d_sp(new FileManager(deviceImpl_p, path),
        FileManager::Deleter());

    return d_sp;
}

//==============================================================================
//      FileManager::isOpen()
//==============================================================================
bool FileManager::isOpen()
{
    return m_inputFileStream.is_open();
}

//==============================================================================
//      FileManager::isCompleted()
//==============================================================================
bool FileManager::isCompleted()
{
    return m_inputFileStream.tellg() >= m_inputFileSize;
}

//==============================================================================
//      FileManager::read()
//==============================================================================
void FileManager::read(std::vector<char>& writeBuff) throw(std::runtime_error)
{
    if(m_inputFileStream.tellg() >= m_inputFileSize)
        throw std::runtime_error("Already completed");

    int leftToRead = m_inputFileSize - m_inputFileStream.tellg();

    int bufferSize = 0;

    if(leftToRead < BUFFER_SIZE)
            bufferSize = leftToRead;
    else
            bufferSize = BUFFER_SIZE;

    writeBuff.resize(bufferSize);

    m_inputFileStream.read(&writeBuff[0], bufferSize);
}

}
